@@ -10,7 +10,7 @@ from drivers.asserts import assert_eq, assert_match
 
 p = run_alr('get', 'does_not_exist', complain_on_error=False)
 assert_eq(1, p.status)
-assert_match('.*Crate \[does_not_exist\] does not exist in the catalog\.\n',
+assert_match('.*Crate \[does_not_exist\] does not exist in the index\.\n',
              p.out)
 assert_eq([], glob('does_not_exist*'))
 
