@@ -2,10 +2,7 @@
 Retrieve a release from a local git repository
 """
 
-from glob import glob
-
-from drivers.alr import run_alr
-from drivers.asserts import assert_match
+from drivers.alr import alr_with, init_local_crate, run_alr
 from drivers.helpers import compare, contents
 
 # Get the release
@@ -19,7 +16,8 @@ compare(list(filter
          'libfoo_1.0.0_9ddda32b/alire',
          'libfoo_1.0.0_9ddda32b/alire.toml',
          'libfoo_1.0.0_9ddda32b/alire/alire.lock',
-         'libfoo_1.0.0_9ddda32b/alire/config.toml',
+         'libfoo_1.0.0_9ddda32b/alire/flags',
+         'libfoo_1.0.0_9ddda32b/alire/flags/complete_copy',
          'libfoo_1.0.0_9ddda32b/b',
          'libfoo_1.0.0_9ddda32b/b/x',
          'libfoo_1.0.0_9ddda32b/b/y',
@@ -27,11 +25,10 @@ compare(list(filter
          'libfoo_1.0.0_9ddda32b/b/y/q',
          'libfoo_1.0.0_9ddda32b/b/z',
          'libfoo_1.0.0_9ddda32b/c',
-         'libfoo_1.0.0_9ddda32b/config',
-         'libfoo_1.0.0_9ddda32b/config/libfoo_config.ads',
-         'libfoo_1.0.0_9ddda32b/config/libfoo_config.gpr',
-         'libfoo_1.0.0_9ddda32b/config/libfoo_config.h'
          ])
 
+# Check as dependency
+init_local_crate()
+run_alr("with", "libfoo")  # should succeed
 
 print('SUCCESS')
