@@ -13,6 +13,9 @@ import shutil
 run_alr('get', 'libhello')
 os.chdir(glob('libhello*')[0])
 
+# Set GNATstudio as prefered editor
+run_alr('settings', '--set', 'editor.cmd', 'gnatstudio -P ${GPR_FILE}')
+
 gs = shutil.which('gnatstudio')
 
 if gs is None:
@@ -27,13 +30,13 @@ else:
     assert_match(".*Please specify a project file with --project=.*", p.out)
 
 # Set an editor that doesn't exist (different than GNAT Studio)
-run_alr('config', '--set', 'editor.cmd', 'doesnt_exist arg1 ab${GPR_FILE}ab arg3')
+run_alr('settings', '--set', 'editor.cmd', 'doesnt_exist arg1 ab${GPR_FILE}ab arg3')
 p = run_alr('edit', '--project=project1.gpr', complain_on_error=False)
 assert_match("ERROR: 'doesnt_exist' not available or not in PATH.*", p.out)
 print(p.out)
 
 # Use echo as an editor to check command line args
-run_alr('config', '--set', 'editor.cmd', 'echo arg1 ab${GPR_FILE}ab arg3')
+run_alr('settings', '--set', 'editor.cmd', 'echo arg1 ab${GPR_FILE}ab arg3')
 p = run_alr('edit', '--project=project1.gpr')
 assert_match("arg1 abproject1.gprab arg3", p.out)
 
